/* ***** BEGIN LICENSE BLOCK *****
 *   Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Thumbs Down.
 *
 * The Initial Developer of the Original Code is
 * Atte Kemppilä.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */


const Cc = Components.classes;
const Ci = Components.interfaces;

var sqlExec;


function onLoad()
{
    stringBundle = $("stringbundle");
}

function onMainPaneLoad() {}

function onUserInterfacePaneLoad() {}

function onScriptsPaneLoad()
{
    sqlExec = new thumbsdown_SqlExecutor(THUMBSDOWN_SQLITE_FILENAME, THUMBSDOWN_SQL_EXECUTOR_CONFIG, THUMBSDOWN_SQL_EXECUTOR_INIT_CONFIG);
    _loadScripts();
    _updateScriptPane();
}

function pickDownloadDir()
{
    var pref = $("pref_downloadDir");
    var dir = Cc["@mozilla.org/file/local;1"].createInstance(Ci.nsILocalFile);
    if (pref.value)
        dir.initWithPath(pref.value);
    if (! (pref.value && dir.exists() && dir.isDirectory()))
        dir = Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties).get("Desk", Ci.nsIFile);
    var fp = Cc["@mozilla.org/filepicker;1"].createInstance(Ci.nsIFilePicker);
    fp.init(window, _("folderPickerTitle"), Ci.nsIFilePicker.modeGetFolder);
    fp.displayDirectory = dir;
    var value = fp.show();
    if (value == Ci.nsIFilePicker.returnOK)
        pref.value = fp.file.path;
}

function onScriptSelect()
{
    _updateScriptPane();
}

function addScript()
{
    var script = _openScriptDialog();
    if (! script)
        return;
    var id = sqlExec.execute("insertScript", script);
    var lbox = $("lbox_scripts");
    var i = 0;
    while ((i < lbox.getRowCount()) && (lbox.getItemAtIndex(i).label < script.name))
        i++;
    if (i == lbox.getRowCount())
        lbox.appendItem(script.name, id)
    else
        lbox.insertItemAt(i, script.name, id);
    lbox.ensureIndexIsVisible(i);
    lbox.selectedIndex = i;
    _updateScriptPane();
    fireDbChanged();
}

function editScript()
{
    var lbox = $("lbox_scripts");
    var item = lbox.selectedItem;
    lbox.ensureElementIsVisible(item);
    var id = item.value;
    var script = sqlExec.fetchOne("getScript", id);
    script = _openScriptDialog(script);
    if (! script)
        return;
    script.id = id;
    sqlExec.execute("updateScript", script);
    item.label = script.name;
    _updateScriptPane();
    fireDbChanged();
}

function removeScript()
{
    var lbox = $("lbox_scripts");
    var item = lbox.selectedItem;
    var index = lbox.selectedIndex;
    lbox.ensureIndexIsVisible(index);
    var id = Number(item.value);
    sqlExec.execute("removeScript", id);
    lbox.removeItemAt(index);
    _updateScriptPane();
    fireDbChanged();
}

function _loadScripts()
{
    var lbox = $("lbox_scripts");
    var scripts = sqlExec.fetchAll("getNames");
    for each (script in scripts)
        lbox.appendItem(script.name, script.id);
}

function _openScriptDialog(script)
{
    var params = {arg: script, result: null}
    document.documentElement.openSubDialog("chrome://thumbsdown/content/script.xul", null, params);
    return params.result;
}

function _updateScriptPane()
{
    var lbox = $("lbox_scripts");
    $("btn_editScript").disabled = (lbox.selectedIndex == -1);
    $("btn_removeScript").disabled = (lbox.selectedIndex == -1);
}
